@@ -29,9 +29,7 @@
 #include <QVector>
 #include "knumber.h"
 
-class KStats
-{
-
+class KStats {
 public:
     KStats();
     ~KStats();
@@ -40,22 +38,20 @@ public:
     void clearAll();
     void enterData(const KNumber &data);
     void clearLast();
-    KNumber sum();
-    KNumber sum_of_squares();
+    KNumber sum() const;
+    KNumber sum_of_squares() const;
     KNumber mean();
     KNumber median();
     KNumber std_kernel();
     KNumber std();
     KNumber sample_std();
     int count() const;
-    bool     error();
+    bool error();
 
 private:
     QVector<KNumber> data_;
-    bool error_flag_;
-
+    bool             error_flag_;
 };
 
-
 #endif
 
